@@ -1,4 +1,6 @@
+from datetime import datetime
 from typing import Any, Dict, List, Optional
+
 from pydantic import BaseModel
 
 
@@ -12,6 +14,7 @@ class Document(BaseModel):
     message_subject: Optional[str] = None
     message_content: Optional[str] = None
     files: List[File] = []
+    upload_date: datetime | None = None  # TODO: make mandatory after 24.11.2025
 
 
 class ClerkCodePayload(BaseModel):
