@@ -161,7 +161,9 @@ class ActionString(BaseModel):
 
     Attributes:
         action_string (str): The string representation of the action.
-        comment (str, optional): An optional comment or description for the action.
+        action_comment (str, optional): An optional comment about the action.
+        observation (str, optional): An optional observation related to the action.
+        interrupt_process (bool, optional): A flag indicating whether the action should interrupt the process.
 
     Methods:
         ensure_format(v: str) -> str:
@@ -170,15 +172,23 @@ class ActionString(BaseModel):
     """
 
     action_string: str
-    comment: Optional[str] = None
+    action_comment: Optional[str] = None
+    observation: Optional[str] = None
+    interrupt_process: Optional[bool] = False
 
     @field_validator("action_string", mode="before")
     @classmethod
     def ensure_format(cls, v: Any):
         if not isinstance(v, str):
             raise ValueError("Action string must be a string")
-        if not v.startswith("LeftClick") and not v.startswith("NoAction"):
-            raise ValueError("Action string must start with 'LeftClick' or 'NoAction'")
         if not v.endswith(".do()") and not v.startswith("NoAction"):
             raise ValueError("Action string must end with '.do()'")
         return v
+
+    @field_validator("interrupt_process", mode="before")
+    def convert_to_bool(cls, v: str | bool | None):
+        if v is None:
+            return False
+        elif isinstance(v, str):
+            return v.lower() in ["true", "1", "yes"]
+        return v
